#ifndef CONFIG_H
#define CONFIG_H

#define TAG_STATE  GTK_STATE_PRELIGHT

#define DEFAULT_LAT 49.02833
#define DEFAULT_LON  8.39042

#ifndef USE_MAEMO
#define DEFAULT_IMAGE_PATH       "/tmp/gpxview/"
#define DEFAULT_IMAGE_PATH_HOME  ".gpxview/"
#define DEFAULT_MMPOI_PATH       "gpxview_poi.db"
#define DEFAULT_GARMIN_PATH      "garmin_overridden.gpx"
#define DEFAULT_FIELDNOTES_PATH  "geocache_visits_%s.txt"
#else
/* internal memory card */
#define DEFAULT_IMAGE_PATH       "/media/mmc2/gpxview/"
#define DEFAULT_MMPOI_PATH       "MyDocs/.documents/Maps/gpxview_poi.db"
#define DEFAULT_GARMIN_PATH      "MyDocs/.documents/garmin_overridden.gpx"
#define DEFAULT_FIELDNOTES_PATH  "MyDocs/.documents/geocache_visits_%s.txt"
#endif

#define LOCALEDIR "/usr/share/locale"
#define PACKAGE   "gpxview"

#endif // CONFIG_H
